@@ -1,4 +1,4 @@
-"""An asyncio-based implementation of the file lock."""  # noqa: A005
+"""An asyncio-based implementation of the file lock."""
 
 from __future__ import annotations
 
@@ -8,6 +8,7 @@ import logging
 import os
 import time
 from dataclasses import dataclass
+from inspect import iscoroutinefunction
 from threading import local
 from typing import TYPE_CHECKING, Any, Callable, NoReturn, cast
 
@@ -265,7 +266,7 @@ class BaseAsyncFileLock(BaseFileLock, metaclass=AsyncFileLockMeta):
                 _LOGGER.debug("Lock %s released on %s", lock_id, lock_filename)
 
     async def _run_internal_method(self, method: Callable[[], Any]) -> None:
-        if asyncio.iscoroutinefunction(method):
+        if iscoroutinefunction(method):
             await method()
         elif self.run_in_executor:
             loop = self.loop or asyncio.get_running_loop()
